@@ -26,11 +26,13 @@ sub run_tests_for_commit {
 
     # get failed tests
     my @failed_desc  = $results->failed;
+    my @exit_desc  = $results->exit;
     $success = $results->all_passed;
 
     unless ($success) {
         # list of failed tests
-        $output = join("\n", map { " - Failed: $_" } @failed_desc);
+        $output  = join("\n", map { " - Failed: $_" } @failed_desc);
+        $output .= join("\n", map { " - Exited unexpectedly: $_" } @exit_desc);
     }
     
     $commit->test_success($success);
